==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/selection/impl/SelectFromInstancesWhereSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.selection.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.ACT_SMTSet;
import io.ciera.tool.sql.ooaofooa.body.impl.ACT_SMTSetImpl;
import io.ciera.tool.sql.ooaofooa.selection.SelectFromInstancesWhere;
import io.ciera.tool.sql.ooaofooa.selection.SelectFromInstancesWhereSet;
import io.ciera.tool.sql.ooaofooa.subsystem.ModelClassSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.ModelClassSetImpl;
import io.ciera.tool.sql.ooaofooa.value.V_VARSet;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.V_VARSetImpl;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.List;


public class SelectFromInstancesWhereSetImpl extends InstanceSet<SelectFromInstancesWhereSet,SelectFromInstancesWhere> implements SelectFromInstancesWhereSet {

    // attributes
    @Override
    public void setExtentColumn( int m_extentColumn ) throws XtumlException {
        for ( SelectFromInstancesWhere selectfrominstanceswhere : this ) selectfrominstanceswhere.setExtentColumn( m_extentColumn );
    }
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( SelectFromInstancesWhere selectfrominstanceswhere : this ) selectfrominstanceswhere.setObj_ID( ref_Obj_ID );
    }
    @Override
    public void setWhere_Clause_Value_ID( UniqueId ref_Where_Clause_Value_ID ) throws XtumlException {
        for ( SelectFromInstancesWhere selectfrominstanceswhere : this ) selectfrominstanceswhere.setWhere_Clause_Value_ID( ref_Where_Clause_Value_ID );
    }
    @Override
    public void setCardinality( String m_cardinality ) throws XtumlException {
        for ( SelectFromInstancesWhere selectfrominstanceswhere : this ) selectfrominstanceswhere.setCardinality( m_cardinality );
    }
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( SelectFromInstancesWhere selectfrominstanceswhere : this ) selectfrominstanceswhere.setStatement_ID( ref_Statement_ID );
    }
    @Override
    public void setIs_implicit( boolean m_is_implicit ) throws XtumlException {
        for ( SelectFromInstancesWhere selectfrominstanceswhere : this ) selectfrominstanceswhere.setIs_implicit( m_is_implicit );
    }
    @Override
    public void setVar_ID( UniqueId ref_Var_ID ) throws XtumlException {
        for ( SelectFromInstancesWhere selectfrominstanceswhere : this ) selectfrominstanceswhere.setVar_ID( ref_Var_ID );
    }
    @Override
    public void setExtentLineNumber( int m_extentLineNumber ) throws XtumlException {
        for ( SelectFromInstancesWhere selectfrominstanceswhere : this ) selectfrominstanceswhere.setExtentLineNumber( m_extentLineNumber );
    }


    // selections
    @Override
    public ACT_SMTSet R603_is_a_ACT_SMT() throws XtumlException {
        ACT_SMTSet act_smtset = new ACT_SMTSetImpl();
        for ( SelectFromInstancesWhere selectfrominstanceswhere : this ) act_smtset.add( selectfrominstanceswhere.R603_is_a_ACT_SMT() );
        return act_smtset;
    }
    @Override
    public ValueSet R610_where_clause_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( SelectFromInstancesWhere selectfrominstanceswhere : this ) valueset.add( selectfrominstanceswhere.R610_where_clause_Value() );
        return valueset;
    }
    @Override
    public V_VARSet R665_result_V_VAR() throws XtumlException {
        V_VARSet v_varset = new V_VARSetImpl();
        for ( SelectFromInstancesWhere selectfrominstanceswhere : this ) v_varset.add( selectfrominstanceswhere.R665_result_V_VAR() );
        return v_varset;
    }
    @Override
    public ModelClassSet R676_from_extent_of_ModelClass() throws XtumlException {
        ModelClassSet modelclassset = new ModelClassSetImpl();
        for ( SelectFromInstancesWhere selectfrominstanceswhere : this ) modelclassset.add( selectfrominstanceswhere.R676_from_extent_of_ModelClass() );
        return modelclassset;
    }


    @Override
    public SelectFromInstancesWhere nullElement() {
        return SelectFromInstancesWhereImpl.EMPTY_SELECTFROMINSTANCESWHERE;
    }

    @Override
    public SelectFromInstancesWhereSet emptySet() {
      return new SelectFromInstancesWhereSetImpl();
    }

    @Override
    public SelectFromInstancesWhereSet value() {
        return this;
    }

    @Override
    public List<SelectFromInstancesWhere> elements() {
        return Arrays.asList(toArray(new SelectFromInstancesWhere[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/selection/impl/SelectFromInstancesWhereSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.selection.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.ACT_SMTSet;
import io.ciera.tool.sql.ooaofooa.body.impl.ACT_SMTSetImpl;
import io.ciera.tool.sql.ooaofooa.selection.SelectFromInstancesWhere;
import io.ciera.tool.sql.ooaofooa.selection.SelectFromInstancesWhereSet;
import io.ciera.tool.sql.ooaofooa.subsystem.ModelClassSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.ModelClassSetImpl;
import io.ciera.tool.sql.ooaofooa.value.V_VARSet;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.V_VARSetImpl;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class SelectFromInstancesWhereSetImpl extends InstanceSet<SelectFromInstancesWhereSet,SelectFromInstancesWhere> implements SelectFromInstancesWhereSet {

    public SelectFromInstancesWhereSetImpl() {
    }

    public SelectFromInstancesWhereSetImpl(Comparator<? super SelectFromInstancesWhere> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setCardinality( String m_cardinality ) throws XtumlException {
        for ( SelectFromInstancesWhere selectfrominstanceswhere : this ) selectfrominstanceswhere.setCardinality( m_cardinality );
    }
    @Override
    public void setVar_ID( UniqueId ref_Var_ID ) throws XtumlException {
        for ( SelectFromInstancesWhere selectfrominstanceswhere : this ) selectfrominstanceswhere.setVar_ID( ref_Var_ID );
    }
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( SelectFromInstancesWhere selectfrominstanceswhere : this ) selectfrominstanceswhere.setStatement_ID( ref_Statement_ID );
    }
    @Override
    public void setExtentColumn( int m_extentColumn ) throws XtumlException {
        for ( SelectFromInstancesWhere selectfrominstanceswhere : this ) selectfrominstanceswhere.setExtentColumn( m_extentColumn );
    }
    @Override
    public void setWhere_Clause_Value_ID( UniqueId ref_Where_Clause_Value_ID ) throws XtumlException {
        for ( SelectFromInstancesWhere selectfrominstanceswhere : this ) selectfrominstanceswhere.setWhere_Clause_Value_ID( ref_Where_Clause_Value_ID );
    }
    @Override
    public void setIs_implicit( boolean m_is_implicit ) throws XtumlException {
        for ( SelectFromInstancesWhere selectfrominstanceswhere : this ) selectfrominstanceswhere.setIs_implicit( m_is_implicit );
    }
    @Override
    public void setExtentLineNumber( int m_extentLineNumber ) throws XtumlException {
        for ( SelectFromInstancesWhere selectfrominstanceswhere : this ) selectfrominstanceswhere.setExtentLineNumber( m_extentLineNumber );
    }
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( SelectFromInstancesWhere selectfrominstanceswhere : this ) selectfrominstanceswhere.setObj_ID( ref_Obj_ID );
    }


    // selections
    @Override
    public ACT_SMTSet R603_is_a_ACT_SMT() throws XtumlException {
        ACT_SMTSet act_smtset = new ACT_SMTSetImpl();
        for ( SelectFromInstancesWhere selectfrominstanceswhere : this ) act_smtset.add( selectfrominstanceswhere.R603_is_a_ACT_SMT() );
        return act_smtset;
    }
    @Override
    public ValueSet R610_where_clause_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( SelectFromInstancesWhere selectfrominstanceswhere : this ) valueset.add( selectfrominstanceswhere.R610_where_clause_Value() );
        return valueset;
    }
    @Override
    public V_VARSet R665_result_V_VAR() throws XtumlException {
        V_VARSet v_varset = new V_VARSetImpl();
        for ( SelectFromInstancesWhere selectfrominstanceswhere : this ) v_varset.add( selectfrominstanceswhere.R665_result_V_VAR() );
        return v_varset;
    }
    @Override
    public ModelClassSet R676_from_extent_of_ModelClass() throws XtumlException {
        ModelClassSet modelclassset = new ModelClassSetImpl();
        for ( SelectFromInstancesWhere selectfrominstanceswhere : this ) modelclassset.add( selectfrominstanceswhere.R676_from_extent_of_ModelClass() );
        return modelclassset;
    }


    @Override
    public SelectFromInstancesWhere nullElement() {
        return SelectFromInstancesWhereImpl.EMPTY_SELECTFROMINSTANCESWHERE;
    }

    @Override
    public SelectFromInstancesWhereSet emptySet() {
      return new SelectFromInstancesWhereSetImpl();
    }

    @Override
    public SelectFromInstancesWhereSet emptySet(Comparator<? super SelectFromInstancesWhere> comp) {
      return new SelectFromInstancesWhereSetImpl(comp);
    }

    @Override
    public SelectFromInstancesWhereSet value() {
        return this;
    }

    @Override
    public List<SelectFromInstancesWhere> elements() {
        return Arrays.asList(toArray(new SelectFromInstancesWhere[0]));
    }

}
